#
# spec file for package ghc-either
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name either
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.0.1.1
Release:        bp156.4.3
Summary:        Combinators for working with sums
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-profunctors-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroupoids-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-quickcheck2-devel
%endif

%description
Combinators for working with sums.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update either to version 5.0.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri May  3 2019 psimons@suse.com
- Update either to version 5.0.1.1.
  5.0.1.1 [2019.05.02]
  - -------------------
  * Only incur a `semigroups` dependency on pre-8.0 GHCs.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update either to version 5.0.1.
  5.0.1 [2018.07.03]
  - -----------------
  * Make the `Semigroup`, `Apply`, and `Applicative` instances for `Validation`
    lazier.
  * Make `vap` lazier in its second argument.
  * Introduce `vapm`, an even lazier version of `vap` which requires a
    `Monoid` constraint. Also add `apm`, a counterpart for `Validation`.
  * Use `test-framework` and `QuickCheck` in the test suite.
* Mon May 14 2018 psimons@suse.com
- Update either to version 5.
  * Changed the semantics of the `Validation` `Alt` and `Alternative` instances to collect errors.
    The previous implementation did not correctly abide the laws.
  * Added `vap`, for when users want validation like semantics but don't want to convert back and forth to validation all the time. Similarly, added `ealt` to give either's `Alt` semantics to validation.
  * Dropped the deprecated `Control.Monad.Trans.Either`.  Use `Control.Monad.Trans.Except` from `transformers` and/or
    `transformers-compat` instead.
  * Add `MMonad` instance for `EitherT`
  * Deprecate `Control.Monad.Trans.Either` in favor of `Control.Monad.Trans.Except`
  * Add `firstEitherT`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon May 22 2017 psimons@suse.com
- Update to version 4.4.1.1 revision 2 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 4.4.1.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 4.4.1.1 revision 0 with cabal2obs.
* Wed May 11 2016 mimi.vx@gmail.com
- update to 4.4.1.1
  * Fixed building on newer GHCs. (type synonyms require explicit foralls for unused
    variables these days)
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 4.4.1
  * Support mmorph
* Sun May 31 2015 mimi.vx@gmail.com
- update to 4.3.4.1
  * Support `MonadRandom` 0.4
* Sun May 17 2015 mimi.vx@gmail.com
- update to 4.3.4
  * Support `bifunctors` 5, `profunctors` 5, and `semigroupoids` 5.
  * Fixed and enhanced documentation for `eitherToError`.
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
